pub struct TablePath { /* private fields */ }Expand description
A validated, slash-joinable sequence of table path segments.
Implementations
Sourceimpl TablePath
impl TablePath
Sourcepub fn from_segments<I, S>(segments: I) -> Result<Self, TablePathError>
pub fn from_segments<I, S>(segments: I) -> Result<Self, TablePathError>
Build a canonical path from validated segments.
Sourcepub fn parse_absolute(input: &str) -> Result<Self, TablePathRefError>
pub fn parse_absolute(input: &str) -> Result<Self, TablePathRefError>
Parse an absolute textual path reference into a canonical path.
Sourcepub fn push(&mut self, segment: &str) -> Result<(), TablePathError>
pub fn push(&mut self, segment: &str) -> Result<(), TablePathError>
Append segment, validating it with is_legal_table_segment.
Sourcepub fn to_absolute_reference(&self) -> String
pub fn to_absolute_reference(&self) -> String
Format this canonical path as an absolute escaped path reference.
Sourcepub fn resolve(
&self,
reference: &TablePathRef,
) -> Result<Self, TablePathRefError>
pub fn resolve( &self, reference: &TablePathRef, ) -> Result<Self, TablePathRefError>
Resolve reference against this canonical path.